%define upstream_name    File-AtomicWrite
%define upstream_version 1.21

%{?perl_default_filter}

Name:       perl-%{upstream_name}
Version:    %perl_convert_version %{upstream_version}
Release:    %mkrel 3

Summary:    Writes files atomically via rename()
License:    GPL+ or Artistic
Group:      Development/Perl
Url:        https://metacpan.org/release/%{upstream_name}
Source0:    https://cpan.metacpan.org/modules/by-module/File/%{upstream_name}-%{upstream_version}.tar.gz

BuildRequires: perl(Carp)
BuildRequires: perl(Digest::SHA1)
BuildRequires: perl(ExtUtils::MakeMaker) >= 6.480.0
BuildRequires: perl(File::Path)
BuildRequires: perl(File::Spec)
BuildRequires: perl(File::Temp) >= 0.180.0
BuildRequires: perl(IO::Handle)
BuildRequires: perl(Test::More)
BuildRequires: perl(lib)
BuildRequires: perl(strict)
BuildArch:  noarch

%description
This module offers atomic file writes via a temporary file created in the
same directory (and therefore, probably the same partition) as the
specified *file*. After data has been written to the temporary file, the
'rename' call is used to replace the target *file*. The module optionally
supports various sanity checks (*min_size*, *CHECKSUM*) that help ensure
the data is written without errors.

Should anything go awry, the module will 'die' or 'croak'. All calls should
be wrapped in eval blocks:

  eval {
    File::AtomicWrite->write_file(...);
  };
  if ($@) {
    die "uh oh: $@";
  }

%prep
%setup -q -n %{upstream_name}-%{upstream_version}

%build
%__perl Makefile.PL INSTALLDIRS=vendor

%make_build

%check
%make_build test

%install
%make_install

%files
%doc Changes LICENSE META.json META.yml MYMETA.yml README SIGNATURE eg
%{_mandir}/man3/*
%{perl_vendorlib}/*

%changelog
* Mon Mar 21 2022 umeabot <umeabot> 1.210.0-3.mga9
+ Revision: 1810963
- Mageia 9 Mass Rebuild

* Fri Feb 14 2020 umeabot <umeabot> 1.210.0-2.mga8
+ Revision: 1519473
- Mageia 8 Mass Rebuild

* Wed Oct 17 2018 shlomif <shlomif> 1.210.0-1.mga7
+ Revision: 1321453
- update to 1.21

* Thu Sep 20 2018 umeabot <umeabot> 1.190.0-2.mga7
+ Revision: 1283657
- Mageia 7 Mass Rebuild

* Sat Jul 29 2017 sander85 <sander85> 1.190.0-1.mga7
+ Revision: 1132341
- update to 1.19

* Sun Jun 19 2016 pterjan <pterjan> 1.160.0-3.mga6
+ Revision: 1027278
- Rebuild for perl 5.22.2

* Fri Feb 19 2016 umeabot <umeabot> 1.160.0-2.mga6
+ Revision: 968348
- Mageia 6 Mass Rebuild

* Mon Jul 06 2015 sander85 <sander85> 1.160.0-1.mga6
+ Revision: 852092
- update to 1.16

* Sat Oct 18 2014 umeabot <umeabot> 1.150.0-4.mga5
+ Revision: 788116
- Rebuild to potentially add missing dependencies

* Wed Oct 15 2014 umeabot <umeabot> 1.150.0-3.mga5
+ Revision: 747647
- Second Mageia 5 Mass Rebuild

* Tue Sep 16 2014 umeabot <umeabot> 1.150.0-2.mga5
+ Revision: 684704
- Mageia 5 Mass Rebuild

* Tue May 06 2014 jquelin <jquelin> 1.150.0-1.mga5
+ Revision: 620629
- update to 1.15

* Sat Oct 19 2013 umeabot <umeabot> 1.140.0-2.mga4
+ Revision: 527648
- Mageia 4 Mass Rebuild

* Mon Jun 10 2013 jquelin <jquelin> 1.140.0-1.mga4
+ Revision: 441575
- update to 1.14

* Sun Jan 13 2013 umeabot <umeabot> 1.70.0-2.mga3
+ Revision: 367142
- Mass Rebuild - https://wiki.mageia.org/en/Feature:Mageia3MassRebuild

* Sat Oct 27 2012 dlucio <dlucio> 1.70.0-1.mga3
+ Revision: 310625
- imported package perl-File-AtomicWrite


* Fri Oct 26 2012 cpan2dist 1.07-1mga
- initial mageia release, generated with cpan2dist
